@@ -22,9 +22,10 @@
 #include <linux/ioctl.h>
 #include <linux/kernel.h>
 #include <linux/limits.h>
-#include <linux/types.h>
+#include <stdint.h>
+#include <sys/types.h>
 
-#define AUFS_VERSION	"2.1-standalone.tree-39-20110801"
+#define AUFS_VERSION	"3.0-20111107"
 
 /* todo? move this to linux-2.6.19/include/magic.h */
 #define AUFS_SUPER_MAGIC	('a' << 24 | 'u' << 16 | 'f' << 8 | 's')
@@ -32,10 +33,10 @@
 /* ---------------------------------------------------------------------- */
 
 #ifdef CONFIG_AUFS_BRANCH_MAX_127
-typedef __s8 aufs_bindex_t;
+typedef int8_t aufs_bindex_t;
 #define AUFS_BRANCH_MAX 127
 #else
-typedef __s16 aufs_bindex_t;
+typedef int16_t aufs_bindex_t;
 #ifdef CONFIG_AUFS_BRANCH_MAX_511
 #define AUFS_BRANCH_MAX 511
 #elif defined(CONFIG_AUFS_BRANCH_MAX_1023)
@@ -94,15 +95,12 @@ typedef __s16 aufs_bindex_t;
 #define AUFS_WH_PLINKDIR	AUFS_WH_PFX AUFS_PLINKDIR_NAME
 #define AUFS_WH_ORPHDIR		AUFS_WH_PFX AUFS_ORPHDIR_NAME
 
-/* branch permission */
+/* branch permissions and attributes */
 #define AUFS_BRPERM_RW		"rw"
 #define AUFS_BRPERM_RO		"ro"
 #define AUFS_BRPERM_RR		"rr"
-#define AUFS_BRPERM_WH		"wh"
-#define AUFS_BRPERM_NLWH	"nolwh"
-#define AUFS_BRPERM_ROWH	AUFS_BRPERM_RO "+" AUFS_BRPERM_WH
-#define AUFS_BRPERM_RRWH	AUFS_BRPERM_RR "+" AUFS_BRPERM_WH
-#define AUFS_BRPERM_RWNLWH	AUFS_BRPERM_RW "+" AUFS_BRPERM_NLWH
+#define AUFS_BRRATTR_WH		"wh"
+#define AUFS_BRWATTR_NLWH	"nolwh"
 
 /* ---------------------------------------------------------------------- */
 
@@ -128,23 +126,23 @@ enum {
 /* borrowed from linux/include/linux/compiler-gcc3.h */
 #ifndef __aligned
 #define __aligned(x)			__attribute__((aligned(x)))
-#define __packed			__attribute__((packed))
 #endif
 
+
 struct au_rdu_cookie {
-	__u64		h_pos;
-	__s16		bindex;
-	__u8		flags;
-	__u8		pad;
-	__u32		generation;
+	uint64_t	h_pos;
+	int16_t		bindex;
+	uint8_t		flags;
+	uint8_t		pad;
+	uint32_t	generation;
 } __aligned(8);
 
 struct au_rdu_ent {
-	__u64		ino;
-	__s16		bindex;
-	__u8		type;
-	__u8		nlen;
-	__u8		wh;
+	uint64_t	ino;
+	int16_t		bindex;
+	uint8_t		type;
+	uint8_t		nlen;
+	uint8_t		wh;
 	char		name[0];
 } __aligned(8);
 
@@ -152,12 +150,12 @@ static __inline__ int au_rdu_len(int nlen)
 {
 	/* include the terminating NULL */
 	return ALIGN(sizeof(struct au_rdu_ent) + nlen + 1,
-		     sizeof(__u64));
+		     sizeof(uint64_t));
 }
 
 union au_rdu_ent_ul {
 	struct au_rdu_ent *e;
-	__u64				ul;
+	uint64_t			ul;
 };
 
 enum {
@@ -168,34 +166,46 @@ enum {
 struct aufs_rdu {
 	/* input */
 	union {
-		__u64		sz;	/* AuCtl_RDU */
-		__u64		nent;	/* AuCtl_RDU_INO */
+		uint64_t	sz;	/* AuCtl_RDU */
+		uint64_t	nent;	/* AuCtl_RDU_INO */
 	};
 	union au_rdu_ent_ul	ent;
-	__u16			verify[AufsCtlRduV_End];
+	uint16_t		verify[AufsCtlRduV_End];
 
 	/* input/output */
-	__u32			blk;
+	uint32_t		blk;
 
 	/* output */
 	union au_rdu_ent_ul	tail;
 	/* number of entries which were added in a single call */
-	__u64			rent;
-	__u8			full;
-	__u8			shwh;
+	uint64_t		rent;
+	uint8_t			full;
+	uint8_t			shwh;
 
 	struct au_rdu_cookie	cookie;
 } __aligned(8);
 
-struct aufs_ibusy {
-	__u64		ino, h_ino;
-	__s16		bindex;
+/* ---------------------------------------------------------------------- */
+
+struct aufs_wbr_fd {
+	uint32_t	oflags;
+	int16_t		brid;
 } __aligned(8);
 
+/* ---------------------------------------------------------------------- */
+
+struct aufs_ibusy {
+	uint64_t	ino, h_ino;
+	int16_t		bindex;
+} __aligned(8);
+
+/* ---------------------------------------------------------------------- */
+
 #define AuCtlType		'A'
 #define AUFS_CTL_RDU		_IOWR(AuCtlType, AuCtl_RDU, struct aufs_rdu)
 #define AUFS_CTL_RDU_INO	_IOWR(AuCtlType, AuCtl_RDU_INO, struct aufs_rdu)
-#define AUFS_CTL_WBR_FD		_IO(AuCtlType, AuCtl_WBR_FD)
+#define AUFS_CTL_WBR_FD		_IOW(AuCtlType, AuCtl_WBR_FD, \
+				     struct aufs_wbr_fd)
 #define AUFS_CTL_IBUSY		_IOWR(AuCtlType, AuCtl_IBUSY, struct aufs_ibusy)
 
 #endif /* __AUFS_TYPE_H__ */
